# pyMeasure
Measurement, Analysis and Data Management Software. To load the API interface use from pyMeasure import *.

Installation
------------
1.	Install Anaconda 2.7 from https://www.continuum.io/downloads
2.	Install pyvisa using pip install pyvisa
3.	Install NI-Visa from http://www.ni.com/download/ni-visa-15.0.1/5693/en/
4.	Clone boa repository to Anaconda2/Lib/site-packages
5.	Clone pyMeasure to Anaconda2/Lib/site-packages
6.	Install wx from source forge http://wxpython.org/
7.	In addition, the USB-GPIB interface needs drivers from NI (NI488.2 version 15) and a computer restart.

Optional Dependencies
----------------------
1. Inkscape from https://inkscape.org/en/download/
2. Microscoft Office
3. pdfkit and wkhtmltopdf pip install pdfkit and install from http://wkhtmltopdf.org/
4. statistiCAL and Microwave Uncertainty Framework from  http://www.nist.gov/ctl/rf-technology/related-software.cfm


License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or distribute this software, either in source code form or as a compiled binary, for any purpose, commercial or non-commercial, and by any means.

In jurisdictions that recognize copyright laws, the author or authors of this software dedicate any and all copyright interest in the software to the public domain. We make this dedication for the benefit of the public at large and to the detriment of our heirs and successors. We intend this dedication to be an overt act of relinquishment in perpetuity of all present and future rights to this software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to http://unlicense.org/
